==> xlockmore-5.46.tar.xz: xlockmore-5.46/xlock/automata.c <==
#if !defined( lint ) && !defined( SABER )
static const char sccsid[] = "@(#)automata.c	4.10 98/04/28 xlockmore";

#endif

/*-
 * automata.c - special stuff for automata modes
 *
 * Copyright (c) 1998 by David Bagley
 *
 * Revision History:
 *
 * Changes maintained by David Bagley <bagleyd@tux.org>
 * 20-Apr-98: Separated out of util.c
 *
 */

#if STANDALONE
#include "utils.h"
#else
#include "xlock.h"

#endif
#include "automata.h"

XPoint      hexagonUnit[6] =
{
	{0, 0},
	{1, 1},
	{0, 2},
	{-1, 1},
	{-1, -1},
	{0, -2}
};

XPoint      triangleUnit[2][3] =
{
	{
		{0, 0},
		{1, -1},
		{0, 2}
	},
	{
		{0, 0},
		{-1, 1},
		{0, -2}
	}
};

XPoint      pentagonUnit[4][5] =
{
	{
		{0, 0},
		{-2, -1},
		{1, -2},
		{2, 0},
		{1, 2}
	},
	{ /* left */
		{0, 0},
		{1, -2},
		{2, 1},
		{0, 2},
		{-2, 1}
	},
	{ /* up */
		{0, 0},
		{2, 1},
		{-1, 2},
		{-2, 0},
		{-1, -2}
	},
	{ /* right */
		{0, 0},
		{-1, 2},
		{-2, -1},
		{0, -2},
		{2, -1}
	}
};

unsigned char stipples[NUMSTIPPLES][STIPPLESIZE] =
{
	{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},	/* white */
	{0x11, 0x22, 0x11, 0x22, 0x11, 0x22, 0x11, 0x22},	/* grey+white | stripe */
	{0x00, 0x66, 0x66, 0x00, 0x00, 0x66, 0x66, 0x00},	/* spots */
	{0x88, 0x44, 0x22, 0x11, 0x88, 0x44, 0x22, 0x11},	/* lt. / stripe */
	{0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66},	/* | bars */
	{0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa},	/* 50% grey */
	{0xff, 0xff, 0x00, 0x00, 0xff, 0xff, 0x00, 0x00},	/* - bars */
	{0xee, 0xdd, 0xbb, 0x77, 0xee, 0xdd, 0xbb, 0x77},	/* dark \ stripe */
	{0xff, 0x99, 0x99, 0xff, 0xff, 0x99, 0x99, 0xff},	/* spots */
	{0xaa, 0xff, 0xff, 0x55, 0xaa, 0xff, 0xff, 0x55},	/* black+grey - stripe */
	{0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff}	/* black */
};

==> xlockmore-5.88.tar.xz: xlockmore-5.88/xlock/automata.c <==
#if 0
static const char sccsid[] = "@(#)automata.c	4.10 98/04/28 xlockmore";

#endif

/*-
 * automata.c - special stuff for automata modes
 *
 * Copyright (c) 1998 by David Bagley
 *
 * Revision History:
 *
 * Changes maintained by David Bagley <bagleyd AT verizon.net>
 * 20-Apr-98: Separated out of util.c
 *
 */

#if STANDALONE
#include "utils.h"
#else
#include "xlock.h"

#endif
#include "automata.h"

XPoint      hexagonUnit[6] =
{
	{0, 0},
	{1, 1},
	{0, 2},
	{-1, 1},
	{-1, -1},
	{0, -2}
};

XPoint      triangleUnit[2][3] =
{
	{
		{0, 0},
		{1, -1},
		{0, 2}
	},
	{
		{0, 0},
		{-1, 1},
		{0, -2}
	}
};

XPoint      pentagonUnit[4][5] =
{
	{
		{0, 0},
		{-2, -1},
		{1, -2},
		{2, 0},
		{1, 2}
	},
	{ /* left */
		{0, 0},
		{1, -2},
		{2, 1},
		{0, 2},
		{-2, 1}
	},
	{ /* up */
		{0, 0},
		{2, 1},
		{-1, 2},
		{-2, 0},
		{-1, -2}
	},
	{ /* right */
		{0, 0},
		{-1, 2},
		{-2, -1},
		{0, -2},
		{2, -1}
	}
};

unsigned char stipples[NUMSTIPPLES][STIPPLESIZE] =
{
	{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},	/* white */
	{0x11, 0x22, 0x11, 0x22, 0x11, 0x22, 0x11, 0x22},	/* grey+white | stripe */
	{0x00, 0x66, 0x66, 0x00, 0x00, 0x66, 0x66, 0x00},	/* spots */
	{0x88, 0x44, 0x22, 0x11, 0x88, 0x44, 0x22, 0x11},	/* lt. / stripe */
	{0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66},	/* | bars */
	{0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa},	/* 50% grey */
	{0xff, 0xff, 0x00, 0x00, 0xff, 0xff, 0x00, 0x00},	/* - bars */
	{0xee, 0xdd, 0xbb, 0x77, 0xee, 0xdd, 0xbb, 0x77},	/* dark \ stripe */
	{0xff, 0x99, 0x99, 0xff, 0xff, 0x99, 0x99, 0xff},	/* spots */
	{0xaa, 0xff, 0xff, 0x55, 0xaa, 0xff, 0xff, 0x55},	/* black+grey - stripe */
	{0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff}	/* black */
};
